@@ -26,7 +26,6 @@ from highdicom.content import (
 from highdicom.enum import PresentationLUTShapeValues
 from highdicom.pr.content import (
     _add_displayed_area_attributes,
-    _add_equipment_attributes,
     _add_graphic_group_annotation_layer_attributes,
     _add_icc_profile_attributes,
     _add_modality_lut_attributes,
@@ -103,7 +102,7 @@ class GrayscaleSoftcopyPresentationState(SOPClass):
             Images that should be referenced
         series_instance_uid: str
             UID of the series
-        series_number: Union[int, None]
+        series_number: int
             Number of the series within the study
         sop_instance_uid: str
             UID that should be assigned to the instance
@@ -185,7 +184,6 @@ class GrayscaleSoftcopyPresentationState(SOPClass):
             sop_instance_uid=sop_instance_uid,
             sop_class_uid=GrayscaleSoftcopyPresentationStateStorage,
             instance_number=instance_number,
-            manufacturer=manufacturer,
             modality='PR',
             patient_id=ref_im.PatientID,
             transfer_syntax_uid=transfer_syntax_uid,
@@ -199,21 +197,16 @@ class GrayscaleSoftcopyPresentationState(SOPClass):
             referring_physician_name=getattr(
                 ref_im, 'ReferringPhysicianName', None
             ),
-            **kwargs
-        )
-        self.copy_patient_and_study_information(ref_im)
-        self.copy_specimen_information(ref_im)
-
-        # General Equipment
-        _add_equipment_attributes(
-            self,
             manufacturer=manufacturer,
             manufacturer_model_name=manufacturer_model_name,
             software_versions=software_versions,
             device_serial_number=device_serial_number,
             institution_name=institution_name,
-            institutional_department_name=institutional_department_name
+            institutional_department_name=institutional_department_name,
+            **kwargs
         )
+        self.copy_patient_and_study_information(ref_im)
+        self.copy_specimen_information(ref_im)
 
         # Presentation State Identification
         _add_presentation_state_identification_attributes(
@@ -379,7 +372,7 @@ class PseudoColorSoftcopyPresentationState(SOPClass):
             Images that should be referenced.
         series_instance_uid: str
             UID of the series
-        series_number: Union[int, None]
+        series_number: int
             Number of the series within the study
         sop_instance_uid: str
             UID that should be assigned to the instance
@@ -463,7 +456,6 @@ class PseudoColorSoftcopyPresentationState(SOPClass):
             sop_instance_uid=sop_instance_uid,
             sop_class_uid=PseudoColorSoftcopyPresentationStateStorage,
             instance_number=instance_number,
-            manufacturer=manufacturer,
             modality='PR',
             patient_id=ref_im.PatientID,
             transfer_syntax_uid=transfer_syntax_uid,
@@ -477,21 +469,16 @@ class PseudoColorSoftcopyPresentationState(SOPClass):
             referring_physician_name=getattr(
                 ref_im, 'ReferringPhysicianName', None
             ),
-            **kwargs
-        )
-        self.copy_patient_and_study_information(ref_im)
-        self.copy_specimen_information(ref_im)
-
-        # General Equipment
-        _add_equipment_attributes(
-            self,
             manufacturer=manufacturer,
             manufacturer_model_name=manufacturer_model_name,
             software_versions=software_versions,
             device_serial_number=device_serial_number,
             institution_name=institution_name,
-            institutional_department_name=institutional_department_name
+            institutional_department_name=institutional_department_name,
+            **kwargs
         )
+        self.copy_patient_and_study_information(ref_im)
+        self.copy_specimen_information(ref_im)
 
         # Presentation State Identification
         _add_presentation_state_identification_attributes(
@@ -656,7 +643,7 @@ class ColorSoftcopyPresentationState(SOPClass):
             Images that should be referenced
         series_instance_uid: str
             UID of the series
-        series_number: Union[int, None]
+        series_number: int
             Number of the series within the study
         sop_instance_uid: str
             UID that should be assigned to the instance
@@ -730,7 +717,6 @@ class ColorSoftcopyPresentationState(SOPClass):
             sop_instance_uid=sop_instance_uid,
             sop_class_uid=ColorSoftcopyPresentationStateStorage,
             instance_number=instance_number,
-            manufacturer=manufacturer,
             modality='PR',
             patient_id=ref_im.PatientID,
             transfer_syntax_uid=transfer_syntax_uid,
@@ -744,21 +730,16 @@ class ColorSoftcopyPresentationState(SOPClass):
             referring_physician_name=getattr(
                 ref_im, 'ReferringPhysicianName', None
             ),
-            **kwargs
-        )
-        self.copy_patient_and_study_information(ref_im)
-        self.copy_specimen_information(ref_im)
-
-        # General Equipment
-        _add_equipment_attributes(
-            self,
             manufacturer=manufacturer,
             manufacturer_model_name=manufacturer_model_name,
             software_versions=software_versions,
             device_serial_number=device_serial_number,
             institution_name=institution_name,
-            institutional_department_name=institutional_department_name
+            institutional_department_name=institutional_department_name,
+            **kwargs
         )
+        self.copy_patient_and_study_information(ref_im)
+        self.copy_specimen_information(ref_im)
 
         # Presentation State Identification
         _add_presentation_state_identification_attributes(
@@ -860,7 +841,7 @@ class AdvancedBlendingPresentationState(SOPClass):
             which may reused in a following step.
         series_instance_uid: str
             UID of the series
-        series_number: Union[int, None]
+        series_number: int
             Number of the series within the study
         sop_instance_uid: str
             UID that should be assigned to the instance
@@ -935,7 +916,6 @@ class AdvancedBlendingPresentationState(SOPClass):
             sop_instance_uid=sop_instance_uid,
             sop_class_uid=AdvancedBlendingPresentationStateStorage,
             instance_number=instance_number,
-            manufacturer=manufacturer,
             modality='PR',
             patient_id=ref_im.PatientID,
             transfer_syntax_uid=transfer_syntax_uid,
@@ -949,6 +929,12 @@ class AdvancedBlendingPresentationState(SOPClass):
             referring_physician_name=getattr(
                 ref_im, 'ReferringPhysicianName', None
             ),
+            manufacturer=manufacturer,
+            manufacturer_model_name=manufacturer_model_name,
+            software_versions=software_versions,
+            device_serial_number=device_serial_number,
+            institution_name=institution_name,
+            institutional_department_name=institutional_department_name,
             **kwargs
         )
         self.copy_patient_and_study_information(ref_im)
@@ -1019,17 +1005,6 @@ class AdvancedBlendingPresentationState(SOPClass):
             )
         self.BlendingDisplaySequence = blending_display
 
-        # General Equipment
-        _add_equipment_attributes(
-            self,
-            manufacturer=manufacturer,
-            manufacturer_model_name=manufacturer_model_name,
-            software_versions=software_versions,
-            device_serial_number=device_serial_number,
-            institution_name=institution_name,
-            institutional_department_name=institutional_department_name
-        )
-
         # Presentation State Identification
         _add_presentation_state_identification_attributes(
             self,
