@@ -211,7 +211,7 @@ class PixelToReferenceTransformer(object):
     pixel of the pixel matrix.
 
     Reference coordinates are (x, y, z) triplets of floating-point values,
-    where the (0.0, 0.0) point is located at the origin of the frame of
+    where the (0.0, 0.0, 0.0) point is located at the origin of the frame of
     reference.
 
     Examples
@@ -347,7 +347,7 @@ class ReferenceToPixelTransformer(object):
     matrix.
 
     Reference coordinates are (x, y, z) triplets of floating-point values,
-    where the (0.0, 0.0) point is located at the origin of the frame of
+    where the (0.0, 0.0, 0.0) point is located at the origin of the frame of
     reference.
 
     Pixel indices are (column, row) pairs of zero-based integer values, where
@@ -497,7 +497,7 @@ class ImageToReferenceTransformer(object):
     sub-pixel resolution.
 
     Reference coordinates are (x, y, z) triplets of floating-point values,
-    where the (0.0, 0.0) point is located at the origin of the frame of
+    where the (0.0, 0.0, 0.0) point is located at the origin of the frame of
     reference. Reference coordinates have millimeter units.
 
     Examples
@@ -630,7 +630,7 @@ class ReferenceToImageTransformer(object):
     to spatial coordinates (SCOORD).
 
     Reference coordinates are (x, y, z) triplets of floating-point values,
-    where the (0.0, 0.0) point is located at the origin of the frame of
+    where the (0.0, 0.0, 0.0) point is located at the origin of the frame of
     reference. Reference coordinates have millimeter units.
 
     Image coordinates are (column, row) pairs of floating-point values, where
@@ -785,8 +785,8 @@ def map_pixel_into_coordinate_system(
 
     Parameters
     ----------
-    index: Sequence[int]
-        Zero-based (column, row) index at pixel resolution in the range
+    index: Sequence[float]
+        (column, row) zero-based index at pixel resolution in the range
         [0, Columns - 1] and [0, Rows - 1], respectively.
     image_position: Sequence[float]
         Position of the slice (image or frame) in the frame of reference, i.e.,
