@@ -1,3 +1,4 @@
+from copy import deepcopy
 import logging
 from typing import Any, Optional, Union
 
@@ -64,13 +65,15 @@ class CodedConcept(Dataset):
             whether `self` and `other` are considered equal
 
         """
-        this = Code(
-            self.value,
-            self.scheme_designator,
-            self.meaning,
-            self.scheme_version
-        )
-        return Code.__eq__(this, other)
+        if isinstance(other, (Code, CodedConcept)):
+            this = Code(
+                self.value,
+                self.scheme_designator,
+                self.meaning,
+                self.scheme_version
+            )
+            return Code.__eq__(this, other)
+        return super().__eq__(other)
 
     def __ne__(self, other: Any) -> bool:
         """Compares `self` and `other` for inequality.
@@ -89,13 +92,21 @@ class CodedConcept(Dataset):
         return not (self == other)
 
     @classmethod
-    def from_dataset(cls, dataset: Dataset) -> 'CodedConcept':
+    def from_dataset(
+        cls,
+        dataset: Dataset,
+        copy: bool = True
+    ) -> 'CodedConcept':
         """Construct a CodedConcept from an existing dataset.
 
         Parameters
         ----------
         dataset: pydicom.dataset.Dataset
             Dataset representing a coded concept.
+        copy: bool
+            If True, the underlying dataset is deep-copied such that the
+            original dataset remains intact. If False, this operation will
+            alter the original dataset in place.
 
         Returns
         -------
@@ -121,12 +132,12 @@ class CodedConcept(Dataset):
                     'Dataset does not contain the following attribute '
                     f'required for coded concepts: {kw}.'
                 )
-        return cls(
-            value=dataset.CodeValue,
-            scheme_designator=dataset.CodingSchemeDesignator,
-            meaning=dataset.CodeMeaning,
-            scheme_version=getattr(dataset, 'CodingSchemeVersion', None)
-        )
+        if copy:
+            concept = deepcopy(dataset)
+        else:
+            concept = dataset
+        concept.__class__ = cls
+        return concept
 
     @classmethod
     def from_code(cls, code: Union[Code, 'CodedConcept']) -> 'CodedConcept':
