@@ -3,15 +3,29 @@ import datetime
 import logging
 from collections import defaultdict
 from copy import deepcopy
-from typing import Any, cast, Mapping, List, Optional, Sequence, Tuple, Union
+from os import PathLike
+from typing import (
+    Any,
+    cast,
+    Mapping,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+    BinaryIO,
+)
 
+from pydicom import dcmread
 from pydicom.dataset import Dataset
 from pydicom.sr.coding import Code
 from pydicom.uid import (
     ExplicitVRLittleEndian,
     ImplicitVRLittleEndian,
     UID,
+    UID_dictionary,
 )
+from pydicom.sequence import Sequence as DataElementSequence
 from pydicom.valuerep import DT, PersonName
 from pydicom.uid import (
     ComprehensiveSRStorage,
@@ -42,7 +56,7 @@ class _SR(SOPClass):
     def __init__(
         self,
         evidence: Sequence[Dataset],
-        content: Dataset,
+        content: Union[Dataset, DataElementSequence],
         series_instance_uid: str,
         series_number: int,
         sop_instance_uid: str,
@@ -72,9 +86,10 @@ class _SR(SOPClass):
             Instances that are referenced in the content tree and from which
             the created SR document instance should inherit patient and study
             information
-        content: pydicom.dataset.Dataset
+        content: Union[pydicom.dataset.Dataset, pydicom.sequence.Sequence]
             Root container content items that should be included in the
-            SR document
+            SR document. This should either be a single dataset, or a sequence
+            of datasets containing a single item.
         series_instance_uid: str
             Series Instance UID of the SR document series
         series_number: int
@@ -209,6 +224,14 @@ class _SR(SOPClass):
             self.PreliminaryFlag = 'PRELIMINARY'
 
         # Add content to dataset
+        if isinstance(content, DataElementSequence):
+            if len(content) != 1:
+                raise ValueError(
+                    "If content is a pydicom.Sequence, it must contain a "
+                    "single element."
+                )
+            content = content[0]
+
         content_copy = deepcopy(content)
         content_item = ContentItem._from_dataset_derived(content_copy)
         self._content = ContentSequence([content_item], is_root=True)
@@ -268,13 +291,17 @@ class _SR(SOPClass):
         return _create_references(group)
 
     @classmethod
-    def from_dataset(cls, dataset: Dataset) -> Dataset:
+    def from_dataset(cls, dataset: Dataset, copy: bool = True) -> Dataset:
         """Construct object from an existing dataset.
 
         Parameters
         ----------
         dataset: pydicom.dataset.Dataset
             Dataset representing a Comprehensive SR document
+        copy: bool
+            If True, the underlying dataset is deep-copied such that the
+            original dataset remains intact. If False, this operation will
+            alter the original dataset in place.
 
         Returns
         -------
@@ -285,7 +312,10 @@ class _SR(SOPClass):
         if not hasattr(dataset, 'ContentSequence'):
             raise ValueError('Dataset is not an SR document.')
         _check_little_endian(dataset)
-        sop_instance = deepcopy(dataset)
+        if copy:
+            sop_instance = deepcopy(dataset)
+        else:
+            sop_instance = dataset
         sop_instance.__class__ = cls
 
         root_item = Dataset()
@@ -298,15 +328,20 @@ class _SR(SOPClass):
             tid_item = dataset.ContentTemplateSequence[0]
             if tid_item.TemplateIdentifier == '1500':
                 sop_instance._content = MeasurementReport.from_sequence(
-                    [root_item]
+                    [root_item],
+                    copy=False,
                 )
             else:
                 sop_instance._content = ContentSequence.from_sequence(
-                    [root_item], is_root=True
+                    [root_item],
+                    is_root=True,
+                    copy=False,
                 )
         except AttributeError:
             sop_instance._content = ContentSequence.from_sequence(
-                [root_item], is_root=True
+                [root_item],
+                is_root=True,
+                copy=False,
             )
 
         return sop_instance
@@ -329,7 +364,7 @@ class EnhancedSR(_SR):
     def __init__(
         self,
         evidence: Sequence[Dataset],
-        content: Dataset,
+        content: Union[Dataset, DataElementSequence],
         series_instance_uid: str,
         series_number: int,
         sop_instance_uid: str,
@@ -358,9 +393,10 @@ class EnhancedSR(_SR):
             Instances that are referenced in the content tree and from which
             the created SR document instance should inherit patient and study
             information
-        content: pydicom.dataset.Dataset
+        content: Union[pydicom.dataset.Dataset, pydicom.sequence.Sequence]
             Root container content items that should be included in the
-            SR document
+            SR document. This should either be a single dataset, or a sequence
+            of datasets containing a single item.
         series_instance_uid: str
             Series Instance UID of the SR document series
         series_number: int
@@ -436,12 +472,12 @@ class EnhancedSR(_SR):
             transfer_syntax_uid=transfer_syntax_uid,
             **kwargs
         )
-        unsopported_content = find_content_items(
-            content,
+        unsupported_content = find_content_items(
+            content if isinstance(content, Dataset) else content[0],
             value_type=ValueTypeValues.SCOORD3D,
             recursive=True
         )
-        if len(unsopported_content) > 0:
+        if len(unsupported_content) > 0:
             raise ValueError(
                 'Enhanced SR does not support content items with '
                 'SCOORD3D value type.'
@@ -459,7 +495,7 @@ class ComprehensiveSR(_SR):
     def __init__(
         self,
         evidence: Sequence[Dataset],
-        content: Dataset,
+        content: Union[Dataset, DataElementSequence],
         series_instance_uid: str,
         series_number: int,
         sop_instance_uid: str,
@@ -488,9 +524,10 @@ class ComprehensiveSR(_SR):
             Instances that are referenced in the content tree and from which
             the created SR document instance should inherit patient and study
             information
-        content: pydicom.dataset.Dataset
+        content: Union[pydicom.dataset.Dataset, pydicom.sequence.Sequence]
             Root container content items that should be included in the
-            SR document
+            SR document. This should either be a single dataset, or a sequence
+            of datasets containing a single item.
         series_instance_uid: str
             Series Instance UID of the SR document series
         series_number: int
@@ -570,7 +607,7 @@ class ComprehensiveSR(_SR):
             **kwargs
         )
         unsupported_content = find_content_items(
-            content,
+            content if isinstance(content, Dataset) else content[0],
             value_type=ValueTypeValues.SCOORD3D,
             recursive=True
         )
@@ -581,13 +618,21 @@ class ComprehensiveSR(_SR):
             )
 
     @classmethod
-    def from_dataset(cls, dataset: Dataset) -> 'ComprehensiveSR':
+    def from_dataset(
+        cls,
+        dataset: Dataset,
+        copy: bool = True,
+    ) -> 'ComprehensiveSR':
         """Construct object from an existing dataset.
 
         Parameters
         ----------
         dataset: pydicom.dataset.Dataset
             Dataset representing a Comprehensive SR document
+        copy: bool
+            If True, the underlying dataset is deep-copied such that the
+            original dataset remains intact. If False, this operation will
+            alter the original dataset in place.
 
         Returns
         -------
@@ -597,7 +642,7 @@ class ComprehensiveSR(_SR):
         """
         if dataset.SOPClassUID != ComprehensiveSRStorage:
             raise ValueError('Dataset is not a Comprehensive SR document.')
-        sop_instance = super().from_dataset(dataset)
+        sop_instance = super().from_dataset(dataset, copy=copy)
         sop_instance.__class__ = ComprehensiveSR
         return cast(ComprehensiveSR, sop_instance)
 
@@ -613,7 +658,7 @@ class Comprehensive3DSR(_SR):
     def __init__(
         self,
         evidence: Sequence[Dataset],
-        content: Dataset,
+        content: Union[Dataset, DataElementSequence],
         series_instance_uid: str,
         series_number: int,
         sop_instance_uid: str,
@@ -641,9 +686,10 @@ class Comprehensive3DSR(_SR):
             Instances that are referenced in the content tree and from which
             the created SR document instance should inherit patient and study
             information
-        content: pydicom.dataset.Dataset
+        content: Union[pydicom.dataset.Dataset, pydicom.sequence.Sequence]
             Root container content items that should be included in the
-            SR document
+            SR document. This should either be a single dataset, or a sequence
+            of datasets containing a single item.
         series_instance_uid: str
             Series Instance UID of the SR document series
         series_number: int
@@ -723,13 +769,21 @@ class Comprehensive3DSR(_SR):
         )
 
     @classmethod
-    def from_dataset(cls, dataset: Dataset) -> 'Comprehensive3DSR':
+    def from_dataset(
+        cls,
+        dataset: Dataset,
+        copy: bool = True
+    ) -> 'Comprehensive3DSR':
         """Construct object from an existing dataset.
 
         Parameters
         ----------
         dataset: pydicom.dataset.Dataset
             Dataset representing a Comprehensive 3D SR document
+        copy: bool
+            If True, the underlying dataset is deep-copied such that the
+            original dataset remains intact. If False, this operation will
+            alter the original dataset in place.
 
         Returns
         -------
@@ -739,6 +793,52 @@ class Comprehensive3DSR(_SR):
         """
         if dataset.SOPClassUID != Comprehensive3DSRStorage:
             raise ValueError('Dataset is not a Comprehensive 3D SR document.')
-        sop_instance = super().from_dataset(dataset)
+        sop_instance = super().from_dataset(dataset, copy=copy)
         sop_instance.__class__ = Comprehensive3DSR
         return cast(Comprehensive3DSR, sop_instance)
+
+
+def srread(
+    fp: Union[str, bytes, PathLike, BinaryIO],
+) -> Union[EnhancedSR, ComprehensiveSR, Comprehensive3DSR]:
+    """Read a Structured Report (SR) document in DICOM File format.
+
+    The object is returned as an instance of the highdicom class corresponding
+    to the dataset's IOD. Currently supported IODs are:
+
+    * Enhanced SR via class :class:`EnhancedSR`
+    * Comprehensive SR via class :class:`ComprehensiveSR`
+    * Comprehensive 3D SR via class :class:`Comprehensive3DSR`
+
+    Parameters
+    ----------
+    fp: Union[str, bytes, os.PathLike]
+        Any file-like object representing a DICOM file containing a
+        supported SR document.
+
+    Raises
+    ------
+    RuntimeError:
+        If the DICOM file has an IOD not supported by highdicom.
+
+    Returns
+    -------
+    Union[highdicom.sr.EnhancedSR, highdicom.sr.ComprehensiveSR, highdicom.sr.Comprehensive3DSR]
+        Structured Report document read from the file.
+
+    """  # noqa: E501
+    class_map = {
+        EnhancedSRStorage: EnhancedSR,
+        ComprehensiveSRStorage: ComprehensiveSR,
+        Comprehensive3DSRStorage: Comprehensive3DSR,
+    }
+    dcm = dcmread(fp)
+
+    sop_class_uid = dcm.SOPClassUID
+    if sop_class_uid in class_map:
+        return class_map[sop_class_uid].from_dataset(dcm, copy=False)
+    else:
+        iod_name = UID_dictionary[sop_class_uid][0]
+        raise RuntimeError(
+            f'SOP Class UID {sop_class_uid} "{iod_name}" is not supported.'
+        )
